Learn R Programming

AovBay (version 0.1.0)

aovbayes: Interactive panel ANOVA classic, non parametric and bayesian

Description

Interactive panel to visualize and develop one-way analysis of variance models, from the classical, non-parametric and Bayesian approach.

Usage

aovbayes(dataset = FALSE)

Arguments

dataset

Data set

Value

A shiny panel with the classical, non-parametric and Bayesian analyzes of variance, based on the specification of the dependent and independent variable of the data set provided in dataset, also provides a decision diagram that suggests which method is appropriate, based on the assumptions of the models.

Examples

Run this code
# NOT RUN {
data(PollutionData)
aovbayes(PollutionData)
# }

Run the code above in your browser using DataLab